@@ -2,13 +2,27 @@ import os
 
 ROOT_DIR = os.path.dirname(os.path.abspath(__file__))
 VOLUME_SCHEMA_FILE = os.path.join(ROOT_DIR, 'volume.json')
+DEFAULT_SERVER_PREFIX = '/nyu/stage/reda/'
 
-VIDEO_EXTENSIONS = ["webm", "mpg", "mp4",
-                    "mov", "mts", "avi",
+VIDEO_EXTENSIONS = ["webm", "mpg",
+                    "mp4", "mov",
+                    "mts", "avi",
                     "wmv", "dv"]
-AUDIO_EXTENSIONS = ["wav", "aac", "wma", "mp3"]
+
+AUDIO_EXTENSIONS = ["wav", "aac",
+                    "wma", "mp3"]
+
 OPF_EXTENSION = ["opf"]
 
+DATABRARY_VOLUME_CATEGORIES = {
+    "1": "participant",
+    "2": "pilot",
+    "3": "exclusion",
+    "4": "condition",
+    "5": "group",
+    "6": "task",
+    "7": "context"
+}
 
 SUPPORTED_FORMATS = {
     "2": "csv",
